==> create-fly-1.21.10-6.0.8-5-sources.jar: com/zurrtum/create/client/AllKeys.java <==
package com.zurrtum.create.client;

import org.lwjgl.glfw.GLFW;

import java.util.ArrayList;
import java.util.List;
import net.minecraft.class_11906;
import net.minecraft.class_2960;
import net.minecraft.class_304;
import net.minecraft.class_304.class_11900;
import net.minecraft.class_310;
import net.minecraft.class_3675;

import static com.zurrtum.create.Create.MOD_ID;

public class AllKeys {
    public static final List<class_304> ALL = new ArrayList<>();
    public static final class_11900 CATEGORY = class_11900.method_74698(class_2960.method_60655(MOD_ID, "binding"));
    public static final class_304 TOOL_MENU = register("toolmenu", GLFW.GLFW_KEY_LEFT_ALT);
    public static final class_304 TOOLBELT = register("toolbelt", GLFW.GLFW_KEY_LEFT_ALT);
    public static final class_304 ROTATE_MENU = register("rotate_menu", GLFW.GLFW_KEY_UNKNOWN);

    private static class_304 register(String name, int code) {
        class_304 key = new class_304("create.keyinfo." + name, code, CATEGORY);
        ALL.add(key);
        return key;
    }

    public static boolean isMouseButtonDown(int button) {
        return GLFW.glfwGetMouseButton(class_310.method_1551().method_22683().method_4490(), button) == 1;
    }

    public static boolean isKeyDown(int key) {
        return GLFW.glfwGetKey(class_310.method_1551().method_22683().method_4490(), key) == 1;
    }

    public static boolean hasControlDown() {
        return class_11906.field_62586 ? class_3675.method_15987(
            class_310.method_1551().method_22683(),
            GLFW.GLFW_KEY_LEFT_SUPER
        ) || class_3675.method_15987(class_310.method_1551().method_22683(), GLFW.GLFW_KEY_RIGHT_SUPER) : class_3675.method_15987(
            class_310.method_1551().method_22683(),
            GLFW.GLFW_KEY_LEFT_CONTROL
        ) || class_3675.method_15987(class_310.method_1551().method_22683(), GLFW.GLFW_KEY_RIGHT_CONTROL);
    }

    public static boolean hasShiftDown() {
        return class_3675.method_15987(class_310.method_1551().method_22683(), GLFW.GLFW_KEY_LEFT_SHIFT) || class_3675.method_15987(
            class_310.method_1551().method_22683(),
            GLFW.GLFW_KEY_RIGHT_SHIFT
        );
    }

    public static void register() {
    }
}

==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/client/AllKeys.java <==
package com.zurrtum.create.client;

import org.lwjgl.glfw.GLFW;

import java.util.ArrayList;
import java.util.List;
import net.minecraft.class_11906;
import net.minecraft.class_2960;
import net.minecraft.class_304;
import net.minecraft.class_304.class_11900;
import net.minecraft.class_310;
import net.minecraft.class_3675;

import static com.zurrtum.create.Create.MOD_ID;

public class AllKeys {
    public static final List<class_304> ALL = new ArrayList<>();
    public static final class_11900 CATEGORY = class_11900.method_74698(class_2960.method_60655(MOD_ID, "binding"));
    public static final class_304 TOOL_MENU = register("toolmenu", GLFW.GLFW_KEY_LEFT_ALT);
    public static final class_304 TOOLBELT = register("toolbelt", GLFW.GLFW_KEY_LEFT_ALT);
    public static final class_304 ROTATE_MENU = register("rotate_menu", GLFW.GLFW_KEY_UNKNOWN);

    private static class_304 register(String name, int code) {
        class_304 key = new class_304("create.keyinfo." + name, code, CATEGORY);
        ALL.add(key);
        return key;
    }

    public static boolean isMouseButtonDown(int button) {
        return GLFW.glfwGetMouseButton(class_310.method_1551().method_22683().method_4490(), button) == 1;
    }

    public static boolean isKeyDown(int key) {
        return GLFW.glfwGetKey(class_310.method_1551().method_22683().method_4490(), key) == 1;
    }

    public static boolean hasControlDown() {
        return class_11906.field_62586 ? class_3675.method_15987(
            class_310.method_1551().method_22683(),
            GLFW.GLFW_KEY_LEFT_SUPER
        ) || class_3675.method_15987(
            class_310.method_1551().method_22683(),
            GLFW.GLFW_KEY_RIGHT_SUPER
        ) : class_3675.method_15987(class_310.method_1551().method_22683(), GLFW.GLFW_KEY_LEFT_CONTROL) || class_3675.method_15987(
            class_310.method_1551().method_22683(),
            GLFW.GLFW_KEY_RIGHT_CONTROL
        );
    }

    public static boolean hasShiftDown() {
        return class_3675.method_15987(
            class_310.method_1551().method_22683(),
            GLFW.GLFW_KEY_LEFT_SHIFT
        ) || class_3675.method_15987(class_310.method_1551().method_22683(), GLFW.GLFW_KEY_RIGHT_SHIFT);
    }

    public static void register() {
    }
}
